TypeSig

Enum TypeSig 

pub enum TypeSig {
    Any,
    Null,
    Bool,
    Int,
    Float,
    String,
    Bytes,
    List(Box<TypeSig>),
    Map(Box<TypeSig>),
    Named(String),
}
A structural type signature used for port compatibility checking.

Variants



Any

Matches any other TypeSig. Use as a wildcard input or output.



Null

The null / absent type.



Bool

Boolean.



Int

64-bit signed integer.



Float

64-bit floating-point number.



String

UTF-8 string.



Bytes

Raw byte sequence.



List(Box<TypeSig>)

Homogeneous list of elements with the given element type.



Map(Box<TypeSig>)

Map with string keys and values of the given type.



Named(String)

A user-defined named type (e.g. a domain struct name).

Implementations

Source

impl TypeSig

pub fn is_compatible_with(&self, other: &TypeSig) -> bool

Returns true if a value with type signature self can be accepted where other is expected.

Rules:

  • Any is compatible with everything (in either position).
  • Named(a) is compatible with Named(b) iff a == b.
  • List(a) is compatible with List(b) iff a is compatible with b.
  • Map(a) is compatible with Map(b) iff a is compatible with b.
  • All other variants require exact equality.